
# plamtral

PLaMTraL - A transfer learning library for pre-trained language models.


## Authors

- [@Vibhu04](https://www.github.com/Vibhu04)


## Installation

Install plamtral with pip:

```bash
pip install plamtral
```

## Requirements

* torch 1.12.1+cu113
* tqdm 4.64.1
* transformers 4.24.0
* nltk 3.7
* torchmetrics
    